==> Rcmdr_1.9-1.tar.gz: Rcmdr/R/globals.R <==
# last modified 2012-08-29 by J. Fox

if (getRversion() >= "2.15.1")  
    globalVariables(c('top', 'statisticFrame', 'statisticVariable', 'buttonsFrame',
                      '.activeModel', 'varVariable', 'rhsVariable', 'varFrame', 'formulaFrame',
                      'outerOperatorsFrame', 'xBox', 'matrixVariable', 'factorCorVariable',
                      'identifyVariable', 'robustVariable', 'matrixFrame', 'factorCorFrame',
                      'identifyFrame', 'robustFrame', 'regexprVariable', 'caseVariable',
                      'directionVariable', 'optionsFrame', 'directionFrame', 'putRExcel',
                      '.commander.done', 'altHypothesisVariable', 'altHypothesisFrame', '.Responses',
                      'scaleVariable', 'scaleFrame', 'centerVariable', 'centerFrame', 'console.output',
                      'OKbutton', 'typeFrame', 'messageBox', 'groupsFrame', 'current.print.line',
                      'Xyplot.HH', 'auto.keyVariable', 'outerVariable', 'x.relationVariable',
                      'y.relationVariable', 'x.relationFrame', 'y.relationFrame', 'fittedVariable',
                      'residualsVariable', 'rstudentVariable', 'hatvaluesVariable', 'cookdVariable',
                      'obsNumbersVariable', 'selectFrame', 'typeVariable', 'levelsVariable',
                      'methodVariable', 'subdialog', 'subButtonsFrame', 'entry1', 'onCancel',
                      'levelNames', 'levelsFrame', 'methodFrame', 'correlationsVariable',
                      'correlationsFrame', 'alternativeVariable', 'alternativeFrame', '.x', '.Table',
                      'meanVariable', 'sumVariable', 'sdVariable', 'checkBoxFrame', 'percentsVariable',
                      'chisqVariable', 'chisqComponentsVariable', 'expFreqVariable', 'fisherVariable',
                      '.Test', 'percentsFrame', 'testsFrame', 'delimiterFrame', 'delimiterVariable',
                      'colnamesVariable', 'rownamesVariable', 'quotesVariable', 'subsetVariable',
                      'rotationVariable', 'scoresVariable', '.FA', 'subsetFrame', 'rotationFrame',
                      'scoresFrame', 'subwin', '.Probs', 'lhsVariable', 'onHelp', 'lhsEntry',
                      'distanceTypeVariable', 'distanceTypeFrame', 'queryimportRODBCtable',
                      'variancesVariable', '.groupsLabel', 'variancesFrame', 'helpButton',
                      'numbersButton', 'namesButton', 'cvVariable', 'skewnessVariable',
                      'kurtosisVariable', 'typeButtonsVariable', '.groups', 'skCheckBoxFrame',
                      'typeButtonsFrame', '.Pairs', 'proportionalOddsModel', 'modelTypeVariable',
                      'modelTypeFrame', 'testVariable', 'testFrame', 'screeplotVariable',
                      'addPCVariable', '.PC', 'locationVariable', 'decimalVariable', 'locationFrame',
                      'decimalFrame', 'TempEnv', 'filetypeVariable', 'filetypeFrame', 'jitterXVariable',
                      'jitterYVariable', 'logXVariable', 'logYVariable', 'boxplotsVariable',
                      'lsLineVariable', 'smoothLineVariable', 'spreadVariable', 'diagonalVariable',
                      'diagonalFrame', 'contrastsVariable', 'contrastsFrame', '..', 'hex.1', 'hex.2',
                      'hex.3', 'hex.4', 'hex.5', 'hex.6', 'hex.7', 'hex.8', '.Z', 'partsVariable',
                      'styleVariable', 'trimOutliersVariable', 'showDepthsVariable',
                      'reverseNegativeVariable', 'partsFrame', 'styleFrame', 'criterionVariable',
                      'criterionFrame', 'plotTypeVariable', 'plotTypeFrame', '.RHS',
                      'chisqTestVariable', 'fisherTestVariable', '.commander.done', '.Workbook', '.Datasets', 
                      'getSheets', 'odbcConnectExcel', 'odbcConnectExcel2007', 'odbcConnectAccess', 
                      'odbcConnectAccess2007', 'odbcConnectDbase', 'IQRVariable',  'unitsVariable', 'unitsFrame',
                      'pointsVariable', 'linesVariable'))

==> Rcmdr_1.9-6.tar.gz: Rcmdr/R/globals.R <==
# last modified 2012-08-29 by J. Fox

if (getRversion() >= "2.15.1")  
    globalVariables(c('top', 'statisticFrame', 'statisticVariable', 'buttonsFrame',
                      '.activeModel', 'varVariable', 'rhsVariable', 'varFrame', 'formulaFrame',
                      'outerOperatorsFrame', 'xBox', 'matrixVariable', 'factorCorVariable',
                      'identifyVariable', 'robustVariable', 'matrixFrame', 'factorCorFrame',
                      'identifyFrame', 'robustFrame', 'regexprVariable', 'caseVariable',
                      'directionVariable', 'optionsFrame', 'directionFrame', 'putRExcel',
                      'altHypothesisVariable', 'altHypothesisFrame', '.Responses',
                      'scaleVariable', 'scaleFrame', 'centerVariable', 'centerFrame', 'console.output',
                      'OKbutton', 'typeFrame', 'messageBox', 'groupsFrame', 'current.print.line',
                      'Xyplot.HH', 'auto.keyVariable', 'outerVariable', 'x.relationVariable',
                      'y.relationVariable', 'x.relationFrame', 'y.relationFrame', 'fittedVariable',
                      'residualsVariable', 'rstudentVariable', 'hatvaluesVariable', 'cookdVariable',
                      'obsNumbersVariable', 'selectFrame', 'typeVariable', 'levelsVariable',
                      'methodVariable', 'subdialog', 'subButtonsFrame', 'entry1', 'onCancel',
                      'levelNames', 'levelsFrame', 'methodFrame', 'correlationsVariable',
                      'correlationsFrame', 'alternativeVariable', 'alternativeFrame', '.x', '.Table',
                      'meanVariable', 'sumVariable', 'sdVariable', 'checkBoxFrame', 'percentsVariable',
                      'chisqVariable', 'chisqComponentsVariable', 'expFreqVariable', 'fisherVariable',
                      '.Test', 'percentsFrame', 'testsFrame', 'delimiterFrame', 'delimiterVariable',
                      'colnamesVariable', 'rownamesVariable', 'quotesVariable', 'subsetVariable',
                      'rotationVariable', 'scoresVariable', '.FA', 'subsetFrame', 'rotationFrame',
                      'scoresFrame', 'subwin', '.Probs', 'lhsVariable', 'onHelp', 'lhsEntry',
                      'distanceTypeVariable', 'distanceTypeFrame', 'queryimportRODBCtable',
                      'variancesVariable', '.groupsLabel', 'variancesFrame', 'helpButton',
                      'numbersButton', 'namesButton', 'cvVariable', 'skewnessVariable',
                      'kurtosisVariable', 'typeButtonsVariable', '.groups', 'skCheckBoxFrame',
                      'typeButtonsFrame', '.Pairs', 'proportionalOddsModel', 'modelTypeVariable',
                      'modelTypeFrame', 'testVariable', 'testFrame', 'screeplotVariable',
                      'addPCVariable', '.PC', 'locationVariable', 'decimalVariable', 'locationFrame',
                      'decimalFrame', 'TempEnv', 'filetypeVariable', 'filetypeFrame', 'jitterXVariable',
                      'jitterYVariable', 'logXVariable', 'logYVariable', 'boxplotsVariable',
                      'lsLineVariable', 'smoothLineVariable', 'spreadVariable', 'diagonalVariable',
                      'diagonalFrame', 'contrastsVariable', 'contrastsFrame', '..', 'hex.1', 'hex.2',
                      'hex.3', 'hex.4', 'hex.5', 'hex.6', 'hex.7', 'hex.8', '.Z', 'partsVariable',
                      'styleVariable', 'trimOutliersVariable', 'showDepthsVariable',
                      'reverseNegativeVariable', 'partsFrame', 'styleFrame', 'criterionVariable',
                      'criterionFrame', 'plotTypeVariable', 'plotTypeFrame', '.RHS',
                      'chisqTestVariable', 'fisherTestVariable', '.commander.done', '.Workbook', '.Datasets', 
                      'getSheets', 'odbcConnectExcel', 'odbcConnectExcel2007', 'odbcConnectAccess', 
                      'odbcConnectAccess2007', 'odbcConnectDbase', 'IQRVariable',  'unitsVariable', 'unitsFrame',
                      'pointsVariable', 'linesVariable'))
